copCAR model object.Return the estimated covariance matrix for a copCAR model object.
# S3 method for copCAR
vcov(object, ...)a fitted copCAR model object.
additional arguments.
An estimate of the covariance matrix of the CE/CML/DT estimator of the parameters.
Unless copCAR was called with confint = "none", this function returns an estimate of the covariance matrix of the CE/CML/DT estimator of the parameters. If confint = "bootstrap", cov is applied to the bootstrap sample to compute the estimate. If confint = "asymptotic", an estimate of the asymptotic covariance matrix is returned; this is an estimate of the inverse Fisher information matrix if method = "CE", or an estimate of the inverse of the Godambe information matrix if method = "CML" or method = "DT". Note that the entries involving the spatial dependence parameter are for \(\gamma=\Phi^{-1}(\rho)\) rather than for \(\rho\) (Hughes, 2015).
Hughes, J. (2015) copCAR: A flexible regression model for areal data. Journal of Computational and Graphical Statistics, 24(3), 733--755.